@@ -26,6 +26,9 @@ class TML:
                 continue
             else:
                 self.content_type = key
+                # Some answers have additional properties later ("display_headline_column"), so need to break after
+                # the actual content_type is found to not overwrite
+                break
 
     def _first_level_property(self, property_key):
         if property_key in self.content:
@@ -569,30 +572,34 @@ class Pinboard(TML):
         v_id = answer['id']
         new_layout_tiles = []
         layout_tiles = self.layout_tiles
-        for tile in layout_tiles:
-            if tile['visualization_id'] == v_id:
-                continue
-            else:
-                new_layout_tiles.append(tile)
-        self.layout_tiles = new_layout_tiles
+        # Layout may not exist
+        if layout_tiles is not None:
+            for tile in layout_tiles:
+                if tile['visualization_id'] == v_id:
+                    continue
+                else:
+                    new_layout_tiles.append(tile)
+            self.layout_tiles = new_layout_tiles
 
     def remove_answer_by_layout_index(self, index: int):
         # Index of the Answer in the layout section, and then the reference in the Answer section is found nad removed
 
         # Needs to delete both the Answer and its reference in the Layout Tiles
+
         layout_tiles = self.layout_tiles
-        layout_answer = layout_tiles.pop(index)
-        self.layout_tiles = layout_tiles
-        # Now find the answer in the visualizations
-        answer = self.content['visualizations']
-        v_id = layout_answer['visualization_id']
-        new_answers = []
-        for answer in self.visualizations:
-            if answer['id'] == v_id:
-                continue
-            else:
-                new_answers.append(answer)
-        self.content['visualizations'] = new_answers
+        if layout_tiles is not None:
+            layout_answer = layout_tiles.pop(index)
+            self.layout_tiles = layout_tiles
+            # Now find the answer in the visualizations
+            answer = self.content['visualizations']
+            v_id = layout_answer['visualization_id']
+            new_answers = []
+            for answer in self.visualizations:
+                if answer['id'] == v_id:
+                    continue
+                else:
+                    new_answers.append(answer)
+            self.content['visualizations'] = new_answers
 
     def add_answer_by_index(self, answer: Answer, index: int, tile_size: str):
         # Answers need a Viz_ID to be mapped in the Tiles, replaced any GUID
@@ -609,24 +616,32 @@ class Pinboard(TML):
         # Add Answer to Pinboard
         self.content['visualizations'].append(answer.tml)
 
-        # Add to Layout Tiles in the right order
+        # Add to Layout Tiles in the right order, if they exist
         layout_tiles = self.layout_tiles
-        new_tile = {"visualization_id": new_id, "size": tile_size}
-        layout_tiles.insert(index, new_tile)
-        print(layout_tiles)
-        self.layout_tiles = layout_tiles
+        if layout_tiles is not None:
+            new_tile = {"visualization_id": new_id, "size": tile_size}
+            layout_tiles.insert(index, new_tile)
+            print(layout_tiles)
+            self.layout_tiles = layout_tiles
 
     @property
     def layout_tiles(self):
         first_level_key = "layout"
         second_level_key = "tiles"
-        return self.content[first_level_key][second_level_key]
+        # it's possible that 'layout' property doesn't exist, if no changes have been made from default
+        if first_level_key in self.content:
+            return self.content[first_level_key][second_level_key]
+        else:
+            return None
 
     @layout_tiles.setter
     def layout_tiles(self, new_tiles):
         first_level_key = "layout"
         second_level_key = "tiles"
-        self.content[first_level_key][second_level_key] = new_tiles
+        if first_level_key in self.content:
+            self.content[first_level_key][second_level_key] = new_tiles
+        # If the 'layout':'tiles' key doesn't exist, should we create it? Would require replicating the
+
 
     # Pass through to allow hitting all Answers contained with a single pinboard
     # You can also do this individually if working the objects one by one
@@ -708,3 +723,17 @@ class YAMLTML:
             return Liveboard(tml_od)
         elif content_type == 'answer':
             return Answer(tml_od)
+
+    # Factory method to return the object type as string
+    @staticmethod
+    def get_tml_type(tml_yaml_str) -> str:
+        tml_od = YAMLTML.load_string(tml_yaml_str)
+        # TML file outer is always a guid, then the type of Object being modeled
+        content_type = 'tml'
+        for key in tml_od:
+            if key in ["guid", "id"]:
+                continue
+            else:
+                content_type = key
+        return content_type
+
